# Changelog

The package's contents are based on _Signal Processing for Algorithmic Trading_ (to be published) by Jay Damask. 

## 1.0.2

Unit-test tweaks to align with the py 3.13.


## 1.0.1

First release of package and source code. This package was used for my book. I completely expect to heavily revise this package's API while preserving the underlying functionality.

## 0.0.2

Skeletal package release. 




